@@ -24,7 +24,7 @@ from cmd2 import (
 )
 
 DC_TOOLS = [ 'system-tools', 'dev-tools', 'app-services','dataset-services','dl-model-services','dl-model-training-services',
-                'dlstreamer-services','edge-deployment-services','edge-inference-app-services',
+                'dl-streamer-pipeline-services','edge-deployment-services','edge-inference-app-services',
                 'edge-to-cloud-app-services','k8s-services','intel-dev-tools']
 DC_COMMANDS = ['install', 'uninstall', 'enable', 'disable']
 APP_COMMANDS = ['start', 'stop', 'restart']
@@ -32,11 +32,11 @@ APP_COMMANDS = ['start', 'stop', 'restart']
 SUB_TOOLS={
   "system-tools":['sftp', 'ssh', 'vnc', 'no-machine','vim'],
   "dev-tools":['docker', 'docker-compose','jupyter', 'n8n', 'openvino-2021.4','vscode'],
-  "app-services":['telemetry','log-anlytics','perf-analysis','video-playback','rtsp-streamer','configs','benchmark-report'],  
+  "app-services":['system-telemetry','cluster-telemetry','docker-telemetry','log-analytics','perf-analysis','rtsp-streamer','web-video-client'],  
   "dataset-services":['intel','partner','public','synthetic'],
-  "dl-model-services":['dl-model-tools', 'inference-runtimes', 'model-zoo'],
+  "dl-model-services":['dl-model-tools', 'inference-runtimes', 'object-detection-models','object-recognition-models'],
   "dl-model-training-services":['data-engineering-tools', 'datasets', 'model-zoo', 'training-frameworks'],
-  "dlstreamer-services":['audio-pipelines','dl-streamer-tools','multi-sensory-pipelines','video-pipelines'],
+  "dl-streamer-pipeline-services":['audio-pipelines','dl-streamer-tools','multi-sensory-pipelines','video-pipelines'],
   "edge-deployment-services":['cross-plane','health-check','mass','vpshere-vm'],
   "edge-inference-app-services":['healthcare','industrial','market-places','media','retail','safety-security','transportation'],
   "edge-to-cloud-app-services":['seo-samples','seo-reference-implementations','seo-3rd-party-applications'],
@@ -51,9 +51,13 @@ TOOLS={
   "model-zoo":['telemetry','analystics','perf-analysis','web-video-playback','rancher','OKD','tanzu'],
   "data-engineering-tools":['cvat'],
   "datasets":['emotion-recognition','face-detection','object-detection'],
-  "model-zoo":['omz'],
+  "object-detection-models":['face-detection-retail-0005','pedestrian-detection-adas-0002','person-detection-retail-0002','vehicle-detection-adas-0002'],
+  "object-recognition-models":['age-gender-recognition-retail-0013','head-pose-estimation-adas-0001'],
   "training-frameworks":['cnvrg','intel-optimized-pytorch','intel-optimized-tensorflow','kubeflow','one-api','sonoma-creek'],
   "dl-streamer-tools":['dlstreamer','dlstreamer-pipeline-server','dlstreamer-pipeline-zoo','dlstreamer-pipeline-composer','gst-shark'],
+  "audio-pipelines":['audio-event-detection-sample'],
+  "video-pipelines":['action-recognition-sample','human-pose-estimation-sample','vehicle-pedestrian-tracking-sample','face-detection-classification-sample','gvapython-sample','metadata-publishing-sample'],
+  "multi-sensory-pipelines":['multi-sensor-pipeline'],
   "healthcare":['brain-tumor-segmentation','monai','openfl'],
   "industrial":['edge-controls-for-industrial','edge-insights-for-amr','edge-insights-for-industrial','industrial-surface-detect-detection','industrial-textline-recognition','rotor-bearing-defect-detector','textile-defect-classifier','weld-porosity-detection'],
   "market-places":['artifactory','dev-catalog','kube-apps','mrs','rrk'],
@@ -62,7 +66,7 @@ TOOLS={
   "safety-security":['edge-aibox-for-video-analytics','edge-insights-for-vision','smart-video-and-ai-workload','social-distancing-for-retail','social-distancing-for-retail-settings'],
   "transportation":['address-recognition-and-analytics','automatic-license-plate-recognition','cargo-management','drive-behavior-analytics','edge-insights-for-fleet','intelligent-traffic-management','public-transit-analytics','vehicle-event-recording','workzone-analytics'],
   "seo-samples":['openvino-sample-application-in-openness','sample-eaa-test-application','telemetry-sample','video-analytics-services-sample-application-in-openness'],
-  "seo-reference-implementations":['intelligent-connection-management-for-automated-handover','smartvr–livestreaming-of-immersive-media','telehealth-remote-monitoring','wireless-network-ready-intelligent-traffic-management','wireless-network-ready-pcb-defect-detection'],
+  "seo-reference-implementations":['intelligent-connection-management-for-automated-handover','smartvr–livestreaming-of-immersive-media','telehealth-remote-monitoring','wireless-network-ready-intelligent-traffic-management','wireless-network-ready-pcb-defect-detection','network-optimization-and-ai-inferencing-management-for-telepathology'],
   "seo-3rd-party-applications":['a5gnetworks','herta','orbo','qwilt','radisys']
 
 }
@@ -199,6 +203,7 @@ class DC(cmd2.Cmd):
         SUB_TOOLS_1=[]
         CMD_TOOLS=[]
         TM_TOOLS=[]
+        APP_TOOLS=[]
         index_dict={}      
         
         if begidx>3:
@@ -208,6 +213,9 @@ class DC(cmd2.Cmd):
                     SUB_TOOLS_1=SUB_TOOLS[t]
                     # print("subtools:", SUB_TOOLS[t])
                     CMD_TOOLS = DC_COMMANDS
+                    if t == "app-services":
+                       APP_TOOLS =APP_COMMANDS
+
 
                 for st in TOOLS:
                     if line.__contains__(st):
@@ -222,6 +230,13 @@ class DC(cmd2.Cmd):
                 3: TM_TOOLS,
                 4: CMD_TOOLS  # Tab complete using path_complete function at index 3 in command line
                  
+            }
+        elif len(APP_TOOLS) != 0:
+            index_dict = {
+                1: DC_TOOLS,  # Tab complete food items at index 1 in command line
+                2: SUB_TOOLS_1,  # Tab complete sport items at index 2 in command line
+                3: APP_TOOLS,  # Tab complete using path_complete function at index 3 in command line
+                
             }
         else:
             # print("Inside else")
