@@ -15,3 +15,9 @@ spawn $::env(HOME)/.local/bin/edgesoftware install smartvr–livestreaming-of-im
 expect "download:" {send "634e374f-b086-411a-916a-53da4b2739db\n"}
 expect "(Example:: 123.123.123.123):" {send $::env(HOST_IP)\n"}
 expect eof'
+
+echo -e "\n"
+HOST_IP=$(hostname -I | awk '{print $1}')
+echo -e "\e[1;36mTo visualize the results, launch an Internet browser and navigate to:\e[0m"
+echo -e "\e[1;33mhttps://$HOST_IP:31004 \e[0m\n"
+
